@@ -1,49 +1,11 @@
-use crate::magic::transl8::impl_magic;
+use super::transl8::{impl_magic, impl_wrapper, FromV8, ToV8};
 use crate::Error;
-use std::ops::{Deref, DerefMut};
 
-use super::transl8::{FromV8, ToV8};
-
-#[derive(Default, PartialEq, Eq, Debug)]
-pub struct U16String(pub Vec<u16>);
+impl_wrapper!(
+  pub struct U16String(Vec<u16>);
+);
 impl_magic!(U16String);
 
-impl U16String {
-  pub fn with_zeroes(length: usize) -> U16String {
-    U16String(vec![0u16; length])
-  }
-
-  pub fn truncate(&mut self, new_length: usize) {
-    self.0.truncate(new_length);
-    self.0.shrink_to_fit()
-  }
-}
-
-impl Deref for U16String {
-  type Target = [u16];
-  fn deref(&self) -> &[u16] {
-    self.0.deref()
-  }
-}
-
-impl DerefMut for U16String {
-  fn deref_mut(&mut self) -> &mut [u16] {
-    self.0.deref_mut()
-  }
-}
-
-impl AsRef<[u16]> for U16String {
-  fn as_ref(&self) -> &[u16] {
-    self.0.as_ref()
-  }
-}
-
-impl AsMut<[u16]> for U16String {
-  fn as_mut(&mut self) -> &mut [u16] {
-    self.0.as_mut()
-  }
-}
-
 impl ToV8 for U16String {
   fn to_v8<'a>(
     &self,
@@ -78,6 +40,6 @@ impl FromV8 for U16String {
       );
       assert!(written == len);
     }
-    Ok(U16String(buffer))
+    Ok(buffer.into())
   }
 }
